import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scalePoint,
  scaleBand,
  max,
  format,
  extent
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960; //canvas size width
const height = 500; //canvas size height
const margin = {
  top: 20, //top edge of chart
  right: 80, //right edge of chart
  bottom: 60, //bottom edge of chart
  left: 90, //left edge of chart
}; 
const xAxisLabelOffset = 50; //downward shift of X-axis label
const yAxisLabelOffset = 50;  //leftward shift of Y-axis label

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = d => d.Chronically_Absent; //x value
  const xAxisLabel = 'Chronically Absent Rate in MA School Districts'; //x axis label

  const yValue = d => d.Retentions; //y value
  const yAxisLabel = '# of Student Retentions'; //y axis label

  const radiusValue = d => d['Retentions Rate']; //circle value

  const xAxisTickFormat = format('');

  const xScale = scaleLinear() //tried to change this to scaleLog()
    .domain(extent(data, xValue)) 
  	.range([0, innerWidth])
      //My attempt to make a log scale- didn't work.
      //.domain([0,100]) 
      //.range([0, 1000])

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])

  const radiusScale = scaleLinear()
    .domain(extent(data, radiusValue))
    .range([3, 20]); //range of circle sizes

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={8} //amount of downward shift of x-axis labels
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight /
            2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={8} //amount of leftward shift of y-axis labels
        />

        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          circleScale={radiusScale}
          circleValue={radiusValue}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
